#
# spec file for package wildmidi
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2007-2016 Hans de Goede <j.w.r.degoede@hhs.nl>
# Copyright (c) 2016 Pauline Emily <vilene@posteo.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libWildMidi2
Name:           wildmidi
Version:        0.4.6
Release:        2.3
Summary:        Softsynth midi player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://www.mindwerks.net/projects/wildmidi
Source:         https://github.com/Mindwerks/wildmidi/archive/%{name}-%{version}.tar.gz
Source1:        %{name}.cfg
Source98:       baselibs.conf
BuildRequires:  cmake >= 3.1
BuildRequires:  dos2unix
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(openal)
Requires:       %{soname} = %{version}

%description
WildMidi is a software midi player which has a core softsynth library that can
be used with other applications.

%package        devel
Summary:        Development files for %{name}
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n     %{soname}
Summary:        WildMidi Midi Wavetable Synth Lib
License:        LGPL-3.0-or-later
Group:          System/Libraries
Requires:       timidity

%description -n %{soname}
This package contains the WildMidi core softsynth library. The library is
designed to process a midi file and stream out the stereo audio data
through a buffer which an external program can then process further.

%prep
%setup -q -n %{name}-%{name}-%{version}
dos2unix -c ascii COPYING

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

install -d %{buildroot}%{_sysconfdir}/wildmidi
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/wildmidi

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files
%license COPYING docs/license/GPLv3.txt
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files devel
%{_includedir}/%{name}_lib.h
%{_libdir}/libWildMidi.so
%{_libdir}/pkgconfig/wildmidi.pc
%{_libdir}/cmake/WildMidi
%{_mandir}/man3/WildMidi_*.3%{?ext_man}

%files -n %{soname}
%license docs/license/LGPLv3.txt
%{_libdir}/libWildMidi.so.*
%{_mandir}/man5/%{name}.cfg.5%{?ext_man}
%config(noreplace) %{_sysconfdir}/wildmidi

%changelog
* Tue Oct 15 2024 Martin Hauke <mardnh@gmx.de>
- Add baselibs.conf
* Thu Apr 11 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.6
  * A lot of player cleanup and refactoring.
  * Ability to choose which audio output backends to include in the
    build system: see the cmake script for the relevant WANT_???
    options. Player's --help command line switch lists the available
    backends.
  * Improved pkg-config file generation in cmake script.
  * Other minor source clean-ups.
  * CMake project clean-ups. Cmake v3.4 or newer is now required.
* Sat Jan 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.5
  * Fixed MUS drum channels 9 and 15 being swapped if the same file
    is played twice from the same memory buffer.
  * Player: Fixed save midi reading wrong argv if there are no path
    seperators.
  * Other code and build system clean-ups.
* Sun Mar 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to versino 0.4.4
  * Fixed integer overflow in midi parser sample count calculation.
  * Fixed 8 bit ping pong GUS patch loaders.
  * Fixed wrong variable use in reverb code.
  * Reset block status of tty after playback.
  * Fixed broken file name handling for 'save as midi' command
    during playback.
  * Clamp MUS volume commands.
* Sat Feb 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.3
  * New API addition: WildMidi_InitVIO(). It is like WildMidi_Init(),
    but tells the library to use caller-provided functions for file IO.
    See wildmidi_lib.h or the man page WildMidi_InitVIO(3) for details.
  * Fixed a thinko in one of the buffer size checks added in v0.4.2.
  * Fixed possible out of bounds reads in sysex commands (bug #190).
  * Fixed invalid reads during config parse with short patch file names.
  * Do not treat a missing end-of-track marker as an error for type-0
    midi files (bug #183).
  * Fixed bad reading of high delta values in XMI converter (bug #199).
  * Fixed a memory leak when freeing a midi (bug #204).
  * Fixed slurred/echoy playback at quick tempos on looped instruments
    (bug #185).
  * Fixed certain midis sounding different compared to timidity, as if
    instruments not turned off (bug #186).
  * Fixed compilation on systems without libm.
  * Several clean-ups.
* Thu Nov  8 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.2
  * Fixed CVE-2017-11661, CVE-2017-11662, CVE-2017-11663,
    CVE-2017-11664 (Bug #175).
  * Fixed WildMidi_Open() might read beyond buffer with too
    short inputs (Bug #178).
  * Fixed a buffer overflow during playback with malformed midi
    files (Bug #180).
  * GUS patch processing changes to meet users expectations (Bug
    [#132]).
  * Worked around a build failure with newer FreeBSD versions
    failing to retrieve the ONLCR constant (Bug #171).
  * Fixed a minor Windows unicode issue (PR #170).
  * A few other fixes / clean-ups.
- Spec cleanup
* Sun Aug 28 2016 vilene@posteo.net
- Initial openSUSE package based on Fedora’s
